@@ -1,7 +1,7 @@
 
 import os
-from .pandas_redis_store import pipeline_pandas_redis_store
-from .pandas_redis_store import pipeline_pandas_redis_get
+from .redis_store import pipeline_redis_store
+from .redis_store import pipeline_redis_get
 import redis
 from datetime import timedelta
 from nanoid import generate
@@ -19,32 +19,20 @@ def test_redis_store():
     os.environ["DP_RUNID"] = generate('1234567890abcdef', 10)
 
     # Data to store in Redis as parquet
-    data = {
-    "calories": [420, 380, 390],
-    "duration": [50, 40, 45]
-    }
-    import pandas as pd
-    df = pd.DataFrame(data)
-    dfrows = df.shape[0]
+    data = "hi there 123"
 
     # Redis connection
     redisConnect = redis.Redis(host=REDIS_HOST, port=6379, db=0)
-
-    
-    # ---------- STORE PARQUET TO REDIS ------------
     
     # Store the data with key hello - run id will be attached
-    rs = pipeline_pandas_redis_store(StoreKey="hello", DataFrame=df, Redis=redisConnect, Expire=True, ExpireDuration=timedelta(minutes=15))
+    rs = pipeline_redis_store(StoreKey="hello", Value=data, Redis=redisConnect, Expire=True, ExpireDuration=timedelta(minutes=15))
     print(rs)
     assert rs["result"]=="OK"
 
     # ---------- RETRIEVE PARQUET FROM REDIS ------------
 
     # Get the data
-    rsget = pipeline_pandas_redis_get(StoreKey="hello", Redis=redisConnect)
-    print(rsget)
-    df = rsget["dataframe"]
-    print(df.shape[0])
+    rsget = pipeline_redis_get(StoreKey="hello", Redis=redisConnect)
     # Test before and after rows
-    assert df.shape[0] == dfrows
+    assert rsget["value"].decode("utf-8") == data
     assert rsget["result"]=="OK"
\ No newline at end of file
